@@ -1,7 +1,7 @@
-## ID: distn.R, last updated 2020-10-09, F.Osorio and T.Wolodzko
+## ID: distn.R, last updated 2023-05-17, F.Osorio and T.Wolodzko
 
 dlaplace <- function(x, location = 0, scale = 1, log = FALSE)
-{
+{ # density of the Laplace distribution
   if (scale <= 0.0)
     stop("'scale' must be non-negative.")
 
@@ -22,7 +22,7 @@ dlaplace <- function(x, location = 0, scale = 1, log = FALSE)
 }
 
 plaplace <- function(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
-{
+{ # distribution function of the Laplace distribution
   if (scale <= 0.0)
     stop("'scale' must be non-negative.")
 
@@ -44,7 +44,7 @@ plaplace <- function(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALS
 }
 
 qlaplace <- function(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
-{
+{ # quantile function of the Laplace distribution
   if (scale <= 0.0)
     stop("'scale' must be non-negative.")
 
@@ -65,20 +65,44 @@ qlaplace <- function(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALS
   y
 }
 
-rlaplace <- function(n, location = 0, scale = 1)
-{
-  if (scale <= 0.0)
-    stop("'scale' must be non-negative.")
+dmLaplace <-
+function(x, center = rep(0, nrow(Scatter)), Scatter = diag(length(center)), log = FALSE)
+{ # pdf for the multivariate Laplace distribution
+  give.log <- log
+  if (is.data.frame(x))
+    x <- as.matrix(x)
+  else if (!is.matrix(x))
+    stop("'x' must be a matrix or a data frame")
+  if (!all(is.finite(x)))
+    stop("'x' must contain finite values only")
+  n <- nrow(x)
+  p <- ncol(x)
 
-  nloc <- length(location)
-  nscale <- length(scale)
+  if (is.null(center))
+    stop("'center' must be provided")
+  if (isFALSE(center))
+    center <- double(p) # center is zeroed
+  if (!is.vector(center))
+    stop("'center' must be a vector")
+  if (length(center) != p)
+    stop("'center' has incorrect length")
 
-  x <- .C("r_laplace",
-          n = as.integer(n),
-          x = double(n),
-          location = as.double(location),
-          nloc = as.integer(nloc),
-          scale = as.double(scale),
-          nscale = as.integer(nscale))$x
-  x
+  if (is.null(Scatter))
+    stop("'Scatter' matrix must be provided")
+  if (!is.matrix(Scatter))
+    stop("'Scatter' must be a matrix")
+  if (all(dim(Scatter) != c(p,p)))
+    stop("'Scatter' has incorrect dimensions")
+  if (!isSymmetric(Scatter))
+    Scatter <- asSymmetric(Scatter)
+
+  u <- Mahalanobis(x, center, Scatter, inverted = FALSE)
+  R <- chol(Scatter)
+  logdet <- sum(log(diag(R)))
+  logk <- lgamma(.5 * p) - .5 * p * log(pi) - lgamma(p) - (p + 1) * log(2)
+  val <- logk - logdet - .5 * sqrt(u) 
+
+  if (!give.log) val <- exp(val)
+  val
 }
+
